# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKMathematicalMorphologyPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkGrayscaleMorphologicalClosingImageFilterPython
else:
    import _itkGrayscaleMorphologicalClosingImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkFlatStructuringElementPython
import itk.itkImagePython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkPointPython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkSizePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkRGBPixelPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.ITKCommonBasePython
import itk.itkImageRegionPython
import itk.itkNeighborhoodPython
import itk.itkBoxImageFilterPython
import itk.itkImageToImageFilterAPython
import itk.itkImageSourcePython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkImageSourceCommonPython
import itk.itkImageToImageFilterCommonPython
import itk.itkMathematicalMorphologyEnumsPython

def itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_New():
    return itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2.New()

class itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2(itk.itkFlatStructuringElementPython.itkKernelImageFilterIF2IF2SE2):
    r"""Proxy of C++ itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalClosingImageFilterPython.delete_itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2

        Create a new object of the class itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2 in _itkGrayscaleMorphologicalClosingImageFilterPython:
_itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2_swigregister(itkGrayscaleMorphologicalClosingImageFilterIF2IF2SE2)

def itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_New():
    return itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3.New()

class itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3(itk.itkFlatStructuringElementPython.itkKernelImageFilterIF3IF3SE3):
    r"""Proxy of C++ itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalClosingImageFilterPython.delete_itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3

        Create a new object of the class itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3 in _itkGrayscaleMorphologicalClosingImageFilterPython:
_itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3_swigregister(itkGrayscaleMorphologicalClosingImageFilterIF3IF3SE3)

def itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_New():
    return itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2.New()

class itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2(itk.itkFlatStructuringElementPython.itkKernelImageFilterISS2ISS2SE2):
    r"""Proxy of C++ itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalClosingImageFilterPython.delete_itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2

        Create a new object of the class itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2 in _itkGrayscaleMorphologicalClosingImageFilterPython:
_itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2_swigregister(itkGrayscaleMorphologicalClosingImageFilterISS2ISS2SE2)

def itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_New():
    return itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3.New()

class itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3(itk.itkFlatStructuringElementPython.itkKernelImageFilterISS3ISS3SE3):
    r"""Proxy of C++ itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalClosingImageFilterPython.delete_itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3

        Create a new object of the class itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3 in _itkGrayscaleMorphologicalClosingImageFilterPython:
_itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3_swigregister(itkGrayscaleMorphologicalClosingImageFilterISS3ISS3SE3)

def itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_New():
    return itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2.New()

class itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2(itk.itkFlatStructuringElementPython.itkKernelImageFilterIUC2IUC2SE2):
    r"""Proxy of C++ itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalClosingImageFilterPython.delete_itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2

        Create a new object of the class itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2 in _itkGrayscaleMorphologicalClosingImageFilterPython:
_itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2_swigregister(itkGrayscaleMorphologicalClosingImageFilterIUC2IUC2SE2)

def itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_New():
    return itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3.New()

class itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3(itk.itkFlatStructuringElementPython.itkKernelImageFilterIUC3IUC3SE3):
    r"""Proxy of C++ itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_Pointer"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_Clone(self)

    def SetAlgorithm(self, algo):
        r"""
        SetAlgorithm(self, algo)

        Parameters
        ----------
        algo: enum itkMathematicalMorphologyEnums::Algorithm

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_SetAlgorithm(self, algo)

    def GetAlgorithm(self):
        r"""GetAlgorithm(self) -> itkMathematicalMorphologyEnums::Algorithm"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_GetAlgorithm(self)

    def SetSafeBorder(self, _arg):
        r"""
        SetSafeBorder(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_SetSafeBorder(self, _arg)

    def GetSafeBorder(self):
        r"""GetSafeBorder(self) -> bool const &"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_GetSafeBorder(self)

    def SafeBorderOn(self):
        r"""SafeBorderOn(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_SafeBorderOn(self)

    def SafeBorderOff(self):
        r"""SafeBorderOff(self)"""
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_SafeBorderOff(self)
    __swig_destroy__ = _itkGrayscaleMorphologicalClosingImageFilterPython.delete_itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3

        Create a new object of the class itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3 in _itkGrayscaleMorphologicalClosingImageFilterPython:
_itkGrayscaleMorphologicalClosingImageFilterPython.itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3_swigregister(itkGrayscaleMorphologicalClosingImageFilterIUC3IUC3SE3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def grayscale_morphological_closing_image_filter(*args: itkt.ImageLike,  kernel: Union[itkt.FlatStructuringElement, itkt.FlatStructuringElement]=..., algorithm=..., safe_border: bool=..., radius: Union[Sequence[int], int, Sequence[int], int]=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for GrayscaleMorphologicalClosingImageFilter"""
    import itk

    kwarg_typehints = { 'kernel':kernel,'algorithm':algorithm,'safe_border':safe_border,'radius':radius }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.GrayscaleMorphologicalClosingImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def grayscale_morphological_closing_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKMathematicalMorphology.GrayscaleMorphologicalClosingImageFilter
    grayscale_morphological_closing_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    grayscale_morphological_closing_image_filter.__doc__ = filter_object.__doc__



